IcRuntime

Struct IcRuntime 

pub struct IcRuntime { /* private fields */ }
Runtime when interacting with a canister running on the Internet Computer.

Examples

Call the make_http_post_request endpoint on the example http_canister.

use candid::Principal;
use ic_canister_runtime::{IcRuntime, Runtime, StubRuntime};

let runtime = IcRuntime::new();
let http_request_result: String = runtime
    .update_call(canister_id, "make_http_post_request", (), 0)
    .await
    .expect("Call to `http_canister` failed");

assert!(http_request_result.contains("Hello, World!"));
assert!(http_request_result.contains("\"X-Id\": \"42\""));

Implementations

Source

impl IcRuntime

pub fn new() -> Self

Create a new instance of IcRuntime.

pub fn allow_calls_when_stopping(self, allow: bool) -> Self

Allow inter-canister calls when the canister is stopping.

Allowing inter-canister calls when the canister making the calls is stopping could prevent that canister from being stopped and therefore upgraded. This is because the stopping state does not prevent the canister itself from issuing new calls (see the specification on stop_canister).